@@ -15,14 +15,17 @@ class OpenRouter(OpenaiTemplate):
 class OpenRouterFree(OpenRouter):
     parent = "OpenRouter"
     label = "OpenRouter (free)"
+    max_tokens = 5012
 
     @classmethod
     def get_models(cls, api_key: str = None, **kwargs):
         models = super().get_models(api_key=api_key, **kwargs)
-        models = [model for model in models if model.endswith(":free") or model.endswith("/auto")]
+        models = [model for model in models if model.endswith(":free")]
         cls.model_aliases = {model.replace(":free", ""): model for model in models}
-        return [model.replace(":free", "") for model in models]
-    
+        cls.models = [model.replace(":free", "") for model in models]
+        cls.default_model = models[0] if models else cls.default_model
+        return cls.models
+
     @classmethod
     def get_model(cls, model: str, **kwargs) -> str:
         # Load model aliases if not already done
