@@ -42,13 +42,9 @@ from .. import debug
 from .raise_for_status import raise_for_status
 from ..errors import MissingRequirementsError
 from ..typing import Cookies
-from ..cookies import get_cookies_dir
+from ..cookies import BrowserConfig, get_cookies_dir
 from .defaults import DEFAULT_HEADERS, WEBVIEW_HAEDERS
 
-class BrowserConfig:
-    stop_browser = lambda: None
-    browser_executable_path: str = None
-
 if not has_curl_cffi:
     class Session:
         def __init__(self, **kwargs):
@@ -169,9 +165,9 @@ async def get_nodriver(
                 browser_executable_path = None
     debug.log(f"Browser executable path: {browser_executable_path}")
     lock_file = Path(get_cookies_dir()) / ".nodriver_is_open"
-    lock_file.parent.mkdir(exist_ok=True)
-    # Implement a short delay (milliseconds) to prevent race conditions.
     if user_data_dir:
+        lock_file.parent.mkdir(exist_ok=True)
+        # Implement a short delay (milliseconds) to prevent race conditions.
         await asyncio.sleep(0.1 * random.randint(0, 50))
         if lock_file.exists():
             opend_at = float(lock_file.read_text())
@@ -194,10 +190,13 @@ async def get_nodriver(
         lock_file.write_text(str(time.time()))
         debug.log(f"Open nodriver with user_dir: {user_data_dir}")
     try:
+        browser_args = ["--no-sandbox"]
         browser = await nodriver.start(
             user_data_dir=user_data_dir,
-            browser_args=["--no-sandbox"] if proxy is None else ["--no-sandbox", f"--proxy-server={proxy}"],
+            browser_args=[*browser_args, f"--proxy-server={proxy}"] if proxy else browser_args,
             browser_executable_path=browser_executable_path,
+            port=BrowserConfig.port,
+            host=BrowserConfig.host,
             **kwargs
         )
     except FileNotFoundError as e:
@@ -210,7 +209,7 @@ async def get_nodriver(
             raise
     def on_stop():
         try:
-            if browser.connection:
+            if BrowserConfig.port is None and browser.connection:
                 browser.stop()
         except:
             pass
